==> Iyer517_1.4.4.zip: Iyer517/doc/Iyer517.R <==
###################################################
### chunk number 1: 
###################################################
library(Iyer517)


###################################################
### chunk number 2: 
###################################################
show(Iyer517)


###################################################
### chunk number 3: 
###################################################
exprs(Iyer517)[1:4,1:6]


###################################################
### chunk number 4: 
###################################################
chg <- seq(.1,8,.01)
mycol <- rgb( chg/8, 1-chg/8, 0 )
CEX <- exprs(Iyer517)
CEX[CEX>8] <- 8


###################################################
### chunk number 5: 
###################################################
image(t(log10(CEX[517:1,1:13])),col=mycol,xlim=c(0,3),axes=FALSE,
 xlab="Hours post exposure to serum")
axis(1,at=(1:13)/13,lab=c("0",".25",".5","1","2","4","6","8","12","16","20","24","u"),cex=.3)


###################################################
### chunk number 6: 
###################################################
par(mfrow=c(2,2))
plot(apply((CEX[1:100,1:13]),2,mean),main="Cluster A", log="y",
ylab="fold change", xlab="index in timing sequence")
plot(apply((CEX[101:242,1:13]),2,mean),main="Cluster B", log="y",
ylab="fold change", xlab="index in timing sequence")
plot(apply((CEX[483:499,1:13]),2,mean),main="Cluster I", log="y",
ylab="fold change", xlab="index in timing sequence")
plot(apply((CEX[500:517,1:13]),2,mean),main="Cluster J", log="y",
ylab="fold change", xlab="index in timing sequence")


###################################################
### chunk number 7: 
###################################################
data(IyerAnnotated)
print(IyerAnnotated[1:5,])

==> Iyer517_1.4.5.zip: Iyer517/doc/Iyer517.R <==
###################################################
### chunk number 1: 
###################################################
#line 57 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmptmz54I/R.INSTALL7f7749f/Iyer517/inst/doc/Iyer517.Rnw"
library(Iyer517)


###################################################
### chunk number 2: 
###################################################
#line 61 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmptmz54I/R.INSTALL7f7749f/Iyer517/inst/doc/Iyer517.Rnw"
show(Iyer517)


###################################################
### chunk number 3: 
###################################################
#line 65 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmptmz54I/R.INSTALL7f7749f/Iyer517/inst/doc/Iyer517.Rnw"
exprs(Iyer517)[1:4,1:6]


###################################################
### chunk number 4: 
###################################################
#line 82 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmptmz54I/R.INSTALL7f7749f/Iyer517/inst/doc/Iyer517.Rnw"
chg <- seq(.1,8,.01)
mycol <- rgb( chg/8, 1-chg/8, 0 )
CEX <- exprs(Iyer517)
CEX[CEX>8] <- 8


###################################################
### chunk number 5: 
###################################################
#line 89 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmptmz54I/R.INSTALL7f7749f/Iyer517/inst/doc/Iyer517.Rnw"
image(t(log10(CEX[517:1,1:13])),col=mycol,xlim=c(0,3),axes=FALSE,
 xlab="Hours post exposure to serum")
axis(1,at=(1:13)/13,lab=c("0",".25",".5","1","2","4","6","8","12","16","20","24","u"),cex=.3)


###################################################
### chunk number 6: 
###################################################
#line 107 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmptmz54I/R.INSTALL7f7749f/Iyer517/inst/doc/Iyer517.Rnw"
par(mfrow=c(2,2))
plot(apply((CEX[1:100,1:13]),2,mean),main="Cluster A", log="y",
ylab="fold change", xlab="index in timing sequence")
plot(apply((CEX[101:242,1:13]),2,mean),main="Cluster B", log="y",
ylab="fold change", xlab="index in timing sequence")
plot(apply((CEX[483:499,1:13]),2,mean),main="Cluster I", log="y",
ylab="fold change", xlab="index in timing sequence")
plot(apply((CEX[500:517,1:13]),2,mean),main="Cluster J", log="y",
ylab="fold change", xlab="index in timing sequence")


###################################################
### chunk number 7: 
###################################################
#line 122 "E:/biocbld/bbs-2.7-data-experiment/tmpdir/Rtmptmz54I/R.INSTALL7f7749f/Iyer517/inst/doc/Iyer517.Rnw"
data(IyerAnnotated)
print(IyerAnnotated[1:5,])
